###################################
#
#In this R-file we compute all hazard ratios and incidence density ratios listed in table 4
#

# load package Survival
library(survival)

# read the data sets of the healthy candidate bias, time dependent bias, length bias and correct model
data_cor <- readRDS("data_cor_cox_new")
data_hc <- readRDS("data_incor_cox")
data_time_dep  <- readRDS("data_time_dep_mvna")



# adding the age at first election to data set data_cor
age <- matrix(0,108,1)
for(i in seq(1,108))
{
  if((data_cor[i,1]!=data_cor[i-1,1])||i==1)
  {
    age[i] <- data_cor[i,4]
    
    for(j in seq(i,107))
    {
      if(data_cor[i,1]==data_cor[j,1])
      {
        age[j] <- data_cor[i,4]
      }
    }
  }
}

data_cor <- data.frame(data_cor,age)



# transition matrix for cox-model
tra <-  matrix(FALSE, 4, 4, dimnames = list(c("0", "1", "2", "3"), c("0", "1", "2", "3")))
tra[2,4] <- TRUE
tra[3,4] <- TRUE

# get the co-variables for the cox-models
Z_cor <- ifelse(data_cor[,2]==1,1,0)
Z_hc <- ifelse(data_hc[,2]==1,1,0)
Z_time_dep <- ifelse(data_time_dep[,2]==1,1,0)


################# calculating the hazard ratios for the correct model

#fitted cox-model for the correct model
fit_cor1 <- coxph(Surv(entry,exit, to != "cens") ~ Z_cor+cluster(as.factor(matchID)),robust=T, data=data_cor) #basic model
fit_cor2 <- coxph(Surv(entry,exit, to != "cens") ~ Z_cor + strata(country)+cluster(as.factor(matchID)),robust=T, data=data_cor) #strata(country)

summary(fit_cor1)
summary(fit_cor2)


#fitted cox-model with time from election
fit_cor1_elec <- coxph(Surv(entry-age,exit-age, to != "cens") ~ Z_cor+cluster(as.factor(matchID)),robust=T, data=data_cor)
fit_cor2_elec <- coxph(Surv(entry-age,exit-age, to != "cens") ~ Z_cor+age+cluster(as.factor(matchID)),robust=T, data=data_cor)
fit_cor3_elec <- coxph(Surv(entry-age,exit-age, to != "cens") ~ Z_cor +age+ strata(country)+cluster(as.factor(matchID)),robust=T, data=data_cor)

summary(fit_cor1_elec)
summary(fit_cor2_elec)
summary(fit_cor3_elec)


################# calculating hazard ratios for the healthy candidate bias


#fitted cox-model for the healthy candidate bias
fit_hc1 <- coxph(Surv(entry,exit, to != "cens") ~ Z_hc+cluster(as.factor(matchID)),robust=T, data=data_hc) #basic model
fit_hc2 <- coxph(Surv(entry,exit, to != "cens") ~ Z_hc + strata(country)+cluster(as.factor(matchID)),robust=T, data=data_hc) #strata(country)

summary(fit_hc1)
summary(fit_hc2)

#fitted cox-model with time from election
fit_hc1_elec <- coxph(Surv(entry-entry,exit-entry, to != "cens") ~ Z_hc+cluster(as.factor(matchID)),robust=T, data=data_hc)
fit_hc2_elec <- coxph(Surv(entry-entry,exit-entry, to != "cens") ~ Z_hc+entry+cluster(as.factor(matchID)),robust=T, data=data_hc)
fit_hc3_elec <- coxph(Surv(entry-entry,exit-entry, to != "cens") ~ Z_hc +entry+ strata(country)+cluster(as.factor(matchID)),robust=T, data=data_hc)

summary(fit_hc1_elec)
summary(fit_hc2_elec)
summary(fit_hc3_elec)


################# calculating hazard ratios for the time dependent bias


#fitted cox-model for the time dependent bias
fit_time1 <- coxph(Surv(entry,exit, to != "cens") ~ Z_time_dep+cluster(as.factor(matchingID)),robust=T, data=data_time_dep) #basic model
fit_time2 <- coxph(Surv(entry,exit, to != "cens") ~ Z_time_dep + strata(country)+cluster(as.factor(matchingID)),robust=T, data=data_time_dep) #strata(country)
summary(fit_time1)
summary(fit_time2)

#fitted cox-model with time from election 
fit_incor1_elec_tdep <- coxph(Surv(entry-entry,exit-entry, to != "cens") ~ Z_time_dep+cluster(as.factor(matchingID)),robust=T, data=data_time_dep)
fit_incor2_elec_tdep <- coxph(Surv(entry-entry,exit-entry, to != "cens") ~ Z_time_dep+entry+cluster(as.factor(matchingID)),robust=T, data=data_time_dep)
fit_incor3_elec_tdep <- coxph(Surv(entry-entry,exit-entry, to != "cens") ~ Z_time_dep +entry+ strata(country)+cluster(as.factor(matchingID)),robust=T, data=data_time_dep)

summary(fit_incor1_elec_tdep)
summary(fit_incor2_elec_tdep)
summary(fit_incor3_elec_tdep)




################# computing incidence density ratios


#correct model
h1<-18/622
h0<-15/627
h1;h0
hr<-h1/h0                                          #computing the incidence density ratio
hr_u<-exp(log(hr)+1.96*sqrt(1/18 + 1/15))          #upper limit of the 95%-CI
hr_l<-exp(log(hr)-1.96*sqrt(1/18 + 1/15))          #lower limit of the 95%-CI
hr;hr_l;hr_u

#healthy candidate bias
h1<-18/484
h0<-15/581
h1;h0
hr<-h1/h0                                          #computing the incidence density ratio
hr_u<-exp(log(hr)+1.96*sqrt(1/18 + 1/15))          #upper limit of the 95%-CI
hr_l<-exp(log(hr)-1.96*sqrt(1/18 + 1/15))          #lower limit of the 95%-CI
hr;hr_l;hr_u

#time dependent bias
h1<-18/655
h0<-15/594
h1;h0
hr<-h1/h0                                          #computing the incidence density ratio
hr_u<-exp(log(hr)+1.96*sqrt(1/18 + 1/15))          #upper limit of the 95%-CI
hr_l<-exp(log(hr)-1.96*sqrt(1/18 + 1/15))          #lower limit of the 95%-CI
hr;hr_l;hr_u

